exochain-node-0.2.0-beta is not a library.
EXOCHAIN distributed node binary.
Single binary for joining and participating in the constitutional governance network. Every node runs the same verified code with identical CGR kernel enforcement.
Usage